import 'package:flutter/material.dart';
import 'package:shimmer/shimmer.dart';

class ProtonImage extends StatelessWidget {
  // Required
  final String path; // URl path
  final double height; // Container Height
  final double radius; // Container Radious

  // Optional
  final BoxFit imgBoxfit; // Image Boxfit - cover
  final double aspectRatio; // Aspect Ration 1:1
  final Color baseColor; // Base Color -  grey
  final Color highlightColor; // Higlight Color  -  grey shade
  final Color backgroundColor; // Background COlor - white
  final Gradient?
      overlayGradient; // Overlay - default set no gradient - nullable

  const ProtonImage({
    super.key,
    required this.path,
    required this.height,
    required this.radius,
    this.imgBoxfit = BoxFit.cover,
    this.aspectRatio = (1 / 1),
    this.backgroundColor = Colors.white,
    this.baseColor = const Color.fromARGB(
        255, 217, 217, 217), // Equivalent to Colors.grey.shade300
    this.highlightColor = const Color.fromARGB(
        255, 245, 245, 245), // Equivalent to Colors.grey.shade100
    this.overlayGradient,
  });

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      height: height, // General Container Height
      child: AspectRatio(
        aspectRatio: aspectRatio, // Core Aspect Ratio
        child: Stack(
          children: [
            Transform.scale(
              scale: 0.990, // Scallig down shimmer by 0.01
              child: Shimmer.fromColors(
                baseColor: baseColor, // User Selected Colors
                highlightColor: highlightColor, // User Selected Colors
                child: Container(
                  decoration: BoxDecoration(
                    borderRadius: BorderRadius.circular(radius),
                    color: backgroundColor,
                  ),
                ),
              ),
            ),
            Container(
              decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(radius),
                image: DecorationImage(
                  fit: imgBoxfit, // Live Image URL
                  image: NetworkImage(path),
                ),
                gradient: overlayGradient,
              ),
            ),
          ],
        ),
      ),
    );
  }
}
